Index: uspace/drv/ohci/ohci.c
===================================================================
--- uspace/drv/ohci/ohci.c	(revision 66a54cca9f5cd9c1ecc9a96ea5ec1ab1c05590e5)
+++ uspace/drv/ohci/ohci.c	(revision 03eea27e5bfa0d60aac6efd50da401413bc6b24d)
@@ -31,5 +31,5 @@
  */
 /** @file
- * @brief UHCI driver
+ * @brief OHCI driver
  */
 #include <errno.h>
@@ -117,10 +117,10 @@
 /** Initialize hc and rh ddf structures and their respective drivers.
  *
  * @param[in] instance UHCI structure to use.
  * @param[in] device DDF instance of the device to use.
  *
  * This function does all the preparatory work for hc and rh drivers:
  *  - gets device hw resources
  *  - disables UHCI legacy support
  *  - asks for interrupt
  *  - registers interrupt handler
@@ -185,5 +185,5 @@
 	ret = ddf_fun_bind(instance->hc_fun);
 	CHECK_RET_DEST_FUN_RETURN(ret,
-	    "Failed(%d) to bind UHCI device function: %s.\n",
+	    "Failed(%d) to bind OHCI device function: %s.\n",
 	    ret, str_error(ret));
 #undef CHECK_RET_HC_RETURN
@@ -216,5 +216,5 @@
 	ret = ddf_fun_bind(instance->rh_fun);
 	CHECK_RET_FINI_RETURN(ret,
-	    "Failed(%d) to register UHCI root hub.\n", ret);
+	    "Failed(%d) to register OHCI root hub.\n", ret);
 
 	return EOK;
@@ -117,10 +117,10 @@
 /** Initialize hc and rh ddf structures and their respective drivers.
  *
- * @param[in] instance UHCI structure to use.
+ * @param[in] instance OHCI structure to use.
  * @param[in] device DDF instance of the device to use.
  *
@@ -117,10 +117,10 @@
  * This function does all the preparatory work for hc and rh drivers:
  *  - gets device hw resources
- *  - disables UHCI legacy support
+ *  - disables OHCI legacy support
  *  - asks for interrupt
  *  - registers interrupt handler
